@@ -21,6 +21,8 @@
 #ifndef _FASTA_OF_SNP_SITES_
 #define _FASTA_OF_SNP_SITES_
 
+#include <stdio.h>
+
 void create_fasta_of_snp_sites(char filename[], int number_of_snps, char ** bases_for_snps, char ** sequence_names, int number_of_samples);
-#define MAX_FILENAME_SIZE 250
+
 #endif
