@@ -22,6 +22,8 @@
 #ifndef _PHYLIB_OF_SNP_SITES_
 #define _PHYLIB_OF_SNP_SITES_
 
+#include <stdio.h>
+
 void create_phylib_of_snp_sites(char filename[], int number_of_snps, char ** bases_for_snps, char ** sequence_names, int number_of_samples);
-#define MAX_FILENAME_SIZE 250
+
 #endif
