@@ -22,16 +22,27 @@
 #include <string.h>
 #include <check.h>
 #include "check-snp-sites.h"
+#include "check-vcf.h"
 
 
 
 int main (void)
 {
   int number_failed;
-  Suite *s = snp_sites_suite ();
-  SRunner *sr = srunner_create (s);
+  Suite *s;
+  SRunner *sr;
+
+  s = snp_sites_suite ();
+  sr = srunner_create (s);
   srunner_run_all (sr, CK_NORMAL);
   number_failed = srunner_ntests_failed (sr);
   srunner_free (sr);
+
+  s = vcf_suite ();
+  sr = srunner_create (s);
+  srunner_run_all (sr, CK_NORMAL);
+  number_failed += srunner_ntests_failed (sr);
+  srunner_free (sr);
+
   return (number_failed == 0) ? EXIT_SUCCESS : EXIT_FAILURE;
 }
